@@ -207,6 +207,12 @@ class AuthorizeView(View):
 class TokenView(View):
     token_endpoint_class = TokenEndpoint
 
+    def dispatch(self, request, *args, **kwargs):
+        response = super().dispatch(request, *args, **kwargs)
+        response = cors_allow_any(request, response)
+
+        return response
+
     def post(self, request, *args, **kwargs):
         token = self.token_endpoint_class(request)
 
@@ -267,9 +273,7 @@ class ProviderInfoView(View):
         response = super().dispatch(request, *args, **kwargs)
 
         if request.method in ['GET', 'HEAD', 'OPTIONS']:
-            response['Access-Control-Allow-Origin'] = '*'
-            response["Access-Control-Allow-Headers"] = \
-                settings.get('OIDC_ACCESS_CONTROL_ALLOW_HEADERS')
+            response = cors_allow_any(request, response)
 
         return response
 
@@ -287,16 +291,30 @@ class ProviderInfoView(View):
 
         types_supported = [response_type.value for response_type in ResponseType.objects.all()]
         dic['response_types_supported'] = types_supported
+        dic["grant_types_supported"] = ["authorization_code", "implicit", "password", "hybrid", "refresh_token",
+                                        "client_credentials"]
+        dic["token_endpoint_auth_signing_alg_values_supported"] = ["RS256"]
+        dic["request_object_signing_alg_values_supported"] = [None]
+        dic["code_challenge_methods_supported"] = ["plain", "S256"]
+        # NOTE: left out because they may be extended by the user settings, and they are optional fields
+        '''dic["claims_supported"] = ["iss", "sub", "aud", "exp", "iat", "jti", "cnf", "webid", "client_id"] + \
+                                  list(STANDARD_CLAIMS.keys())
+        dic["scopes_supported"] = ["profile", "email", "phone", "address"]'''
 
         dic['jwks_uri'] = site_url + reverse('oidc_provider:jwks')
 
-        dic['id_token_signing_alg_values_supported'] = ['HS256', 'RS256']
+        dic['id_token_signing_alg_values_supported'] = ['RS256']
 
         # See: http://openid.net/specs/openid-connect-core-1_0.html#SubjectIDTypes
         dic['subject_types_supported'] = ['public']
 
         dic['token_endpoint_auth_methods_supported'] = ['client_secret_post',
                                                         'client_secret_basic']
+        dic['claims_parameter_supported'] = False
+        dic['request_parameter_supported'] = False
+        dic['request_uri_parameter_supported'] = False
+        dic['require_request_uri_registration'] = False
+        dic['solid_oidc_supported'] = "https://solid.github.io/authentication-panel/solid-oidc"
 
         if settings.get('OIDC_SESSION_MANAGEMENT_ENABLE'):
             dic['check_session_iframe'] = site_url + reverse('oidc_provider:check-session-iframe')
@@ -319,7 +337,7 @@ class JwksView(View):
                 settings.get('OIDC_ACCESS_CONTROL_ALLOW_HEADERS')
         return response
 
-    def get(self, request, *args, **kwargs):
+    def get_all_keys(self):
         dic = dict(keys=[])
 
         for rsakey in RSAKey.objects.all():
@@ -333,6 +351,10 @@ class JwksView(View):
                 'e': long_to_base64(public_key.e),
             })
 
+        return dic
+
+    def get(self, request, *args, **kwargs):
+        dic = self.get_all_keys()
         response = JsonResponse(dic)
 
         return response
